==> smallrye-open-api-core-3.6.2-sources.jar: io/smallrye/openapi/runtime/scanner/dataobject/DataObjectLogging_$logger.java <==
package io.smallrye.openapi.runtime.scanner.dataobject;

import java.util.Locale;
import java.io.Serializable;
import org.jboss.logging.DelegatingBasicLogger;
import java.lang.String;
import org.jboss.logging.Logger;
import org.jboss.jandex.DotName;
import java.lang.Exception;
import org.jboss.jandex.ParameterizedType;
import org.jboss.jandex.Type;
import org.jboss.logging.BasicLogger;
import java.util.List;
import org.jboss.jandex.AnnotationInstance;
import org.jboss.jandex.ClassInfo;


import static org.jboss.logging.Logger.Level.ERROR;
import static org.jboss.logging.Logger.Level.DEBUG;
import static org.jboss.logging.Logger.Level.WARN;

/**
 * Warning this class consists of generated code.
 */
public class DataObjectLogging_$logger extends DelegatingBasicLogger implements DataObjectLogging, BasicLogger, Serializable {
    private static final long serialVersionUID = 1L;
    private static final String FQCN = DataObjectLogging_$logger.class.getName();
    public DataObjectLogging_$logger(final Logger log) {
        super(log);
    }
    private static final Locale LOCALE = Locale.ROOT;
    protected Locale getLoggingLocale() {
        return LOCALE;
    }
    @Override
    public final void processingFieldAnnotation(final AnnotationInstance annotation, final String propertyKey) {
        super.log.logf(FQCN, DEBUG, null, processingFieldAnnotation$str(), annotation, propertyKey);
    }
    protected String processingFieldAnnotation$str() {
        return "SROAP06000: Processing @Schema annotation %s on a field %s";
    }
    @Override
    public final void invalidAnnotationFormat(final String decimalValue) {
        super.log.logf(FQCN, DEBUG, null, invalidAnnotationFormat$str(), decimalValue);
    }
    protected String invalidAnnotationFormat$str() {
        return "SROAP06001: Annotation value has invalid format: %s";
    }
    @Override
    public final void possibleCycle(final ClassInfo classInfo) {
        super.log.logf(FQCN, DEBUG, null, possibleCycle$str(), classInfo);
    }
    protected String possibleCycle$str() {
        return "SROAP06002: Possible cycle was detected at: %s. Will not search further.";
    }
    @Override
    public final void addingChildNode(final ClassInfo classInfo) {
        super.log.logf(FQCN, DEBUG, null, addingChildNode$str(), classInfo);
    }
    protected String addingChildNode$str() {
        return "SROAP06003: Adding child node to path: %s";
    }
    @Override
    public final void path(final String entry) {
        super.log.logf(FQCN, DEBUG, null, path$str(), entry);
    }
    protected String path$str() {
        return "SROAP06004: Path: %s";
    }
    @Override
    public final void ignoringType(final DotName classInfo) {
        super.log.logf(FQCN, DEBUG, null, ignoringType$str(), classInfo);
    }
    protected String ignoringType$str() {
        return "SROAP06005: Ignoring type that is member of ignore set: %s";
    }
    @Override
    public final void ignoringTypeAndAddingToSet(final DotName classInfo) {
        super.log.logf(FQCN, DEBUG, null, ignoringTypeAndAddingToSet$str(), classInfo);
    }
    protected String ignoringTypeAndAddingToSet$str() {
        return "SROAP06006: Ignoring type and adding to ignore set: %s";
    }
    @Override
    public final void processingArray(final Type type) {
        super.log.logf(FQCN, DEBUG, null, processingArray$str(), type);
    }
    protected String processingArray$str() {
        return "SROAP06007: Processing an array %s";
    }
    @Override
    public final void processingParametrizedType(final ParameterizedType type) {
        super.log.logf(FQCN, DEBUG, null, processingParametrizedType$str(), type);
    }
    protected String processingParametrizedType$str() {
        return "SROAP06008: Processing parameterized type %s";
    }
    @Override
    public final void processingTypeAs(final String type, final String asType) {
        super.log.logf(FQCN, DEBUG, null, processingTypeAs$str(), type, asType);
    }
    protected String processingTypeAs$str() {
        return "SROAP06009: Processing %s. Will treat as an %s.";
    }
    @Override
    public final void processingEnum(final Type type) {
        super.log.logf(FQCN, DEBUG, null, processingEnum$str(), type);
    }
    protected String processingEnum$str() {
        return "SROAP31010: Processing an enum %s";
    }
    @Override
    public final void typeNotInJandexIndex(final Type type) {
        super.log.logf(FQCN, DEBUG, null, typeNotInJandexIndex$str(), type);
    }
    protected String typeNotInJandexIndex$str() {
        return "SROAP31011: Encountered type not in Jandex index that is not well-known type. Will not traverse it: %s";
    }
    @Override
    public final void resolvedType(final Type type, final Type resolvedType) {
        super.log.logf(FQCN, DEBUG, null, resolvedType$str(), type, resolvedType);
    }
    protected String resolvedType$str() {
        return "SROAP31012: Resolved type %s -> %s";
    }
    @Override
    public final void terminalType(final Type type) {
        super.log.logf(FQCN, DEBUG, null, terminalType$str(), type);
    }
    protected String terminalType$str() {
        return "SROAP31013: Is a terminal type %s";
    }
    @Override
    public final void typeVarSubstitution(final Type type, final Type resolvedType) {
        super.log.logf(FQCN, DEBUG, null, typeVarSubstitution$str(), type, resolvedType);
    }
    protected String typeVarSubstitution$str() {
        return "SROAP31014: Attempting to do TYPE_VARIABLE substitution: %s -> %s";
    }
    @Override
    public final void classNotAvailable(final Type type) {
        super.log.logf(FQCN, DEBUG, null, classNotAvailable1$str(), type);
    }
    protected String classNotAvailable1$str() {
        return "SROAP31015: Class for type %s not available";
    }
    @Override
    public final void classNotAvailable(final List<org.jboss.jandex.TypeVariable> typeVariables, final List<Type> arguments) {
        super.log.logf(FQCN, ERROR, null, classNotAvailable2$str(), typeVariables, arguments);
    }
    protected String classNotAvailable2$str() {
        return "SROAP31016: Unanticipated mismatch between type arguments and type variables \nArgs: %s\n Vars:%s";
    }
    @Override
    public final void exceptionReadingEnumJsonValue(final String enumName, final String methodName, final Exception exception) {
        super.log.logf(FQCN, WARN, null, exceptionReadingEnumJsonValue$str(), enumName, methodName, exception);
    }
    protected String exceptionReadingEnumJsonValue$str() {
        return "SROAP31017: Failed to read enumeration values from enum %s method %s with `@JsonValue`: %s";
    }
}

==> smallrye-open-api-core-4.0.6-sources.jar: io/smallrye/openapi/runtime/scanner/dataobject/DataObjectLogging_$logger.java <==
package io.smallrye.openapi.runtime.scanner.dataobject;

import java.util.Locale;
import org.jboss.jandex.ParameterizedType;
import java.io.Serializable;
import org.jboss.jandex.Type;
import org.jboss.logging.DelegatingBasicLogger;
import org.jboss.logging.BasicLogger;
import java.lang.String;
import org.jboss.logging.Logger;
import org.jboss.jandex.DotName;
import org.jboss.jandex.AnnotationInstance;
import java.lang.Exception;
import org.jboss.jandex.ClassInfo;


import static org.jboss.logging.Logger.Level.ERROR;
import static org.jboss.logging.Logger.Level.DEBUG;
import static org.jboss.logging.Logger.Level.WARN;

/**
 * Warning this class consists of generated code.
 */
public class DataObjectLogging_$logger extends DelegatingBasicLogger implements DataObjectLogging, BasicLogger, Serializable {
    private static final long serialVersionUID = 1L;
    private static final String FQCN = DataObjectLogging_$logger.class.getName();
    public DataObjectLogging_$logger(final Logger log) {
        super(log);
    }
    private static final Locale LOCALE = Locale.ROOT;
    protected Locale getLoggingLocale() {
        return LOCALE;
    }
    @Override
    public final void processingFieldAnnotation(final AnnotationInstance annotation, final String propertyKey) {
        super.log.logf(FQCN, DEBUG, null, processingFieldAnnotation$str(), annotation, propertyKey);
    }
    protected String processingFieldAnnotation$str() {
        return "SROAP06000: Processing @Schema annotation %s on a field %s";
    }
    @Override
    public final void invalidAnnotationFormat(final String decimalValue) {
        super.log.logf(FQCN, DEBUG, null, invalidAnnotationFormat$str(), decimalValue);
    }
    protected String invalidAnnotationFormat$str() {
        return "SROAP06001: Annotation value has invalid format: %s";
    }
    @Override
    public final void possibleCycle(final ClassInfo classInfo) {
        super.log.logf(FQCN, DEBUG, null, possibleCycle$str(), classInfo);
    }
    protected String possibleCycle$str() {
        return "SROAP06002: Possible cycle was detected at: %s. Will not search further.";
    }
    @Override
    public final void addingChildNode(final ClassInfo classInfo) {
        super.log.logf(FQCN, DEBUG, null, addingChildNode$str(), classInfo);
    }
    protected String addingChildNode$str() {
        return "SROAP06003: Adding child node to path: %s";
    }
    @Override
    public final void path(final String entry) {
        super.log.logf(FQCN, DEBUG, null, path$str(), entry);
    }
    protected String path$str() {
        return "SROAP06004: Path: %s";
    }
    @Override
    public final void ignoringType(final DotName classInfo) {
        super.log.logf(FQCN, DEBUG, null, ignoringType$str(), classInfo);
    }
    protected String ignoringType$str() {
        return "SROAP06005: Ignoring type that is member of ignore set: %s";
    }
    @Override
    public final void ignoringTypeAndAddingToSet(final DotName classInfo) {
        super.log.logf(FQCN, DEBUG, null, ignoringTypeAndAddingToSet$str(), classInfo);
    }
    protected String ignoringTypeAndAddingToSet$str() {
        return "SROAP06006: Ignoring type and adding to ignore set: %s";
    }
    @Override
    public final void processingArray(final Type type) {
        super.log.logf(FQCN, DEBUG, null, processingArray$str(), type);
    }
    protected String processingArray$str() {
        return "SROAP06007: Processing an array %s";
    }
    @Override
    public final void processingParametrizedType(final ParameterizedType type) {
        super.log.logf(FQCN, DEBUG, null, processingParametrizedType$str(), type);
    }
    protected String processingParametrizedType$str() {
        return "SROAP06008: Processing parameterized type %s";
    }
    @Override
    public final void processingTypeAs(final String type, final String asType) {
        super.log.logf(FQCN, DEBUG, null, processingTypeAs$str(), type, asType);
    }
    protected String processingTypeAs$str() {
        return "SROAP06009: Processing %s. Will treat as an %s.";
    }
    @Override
    public final void processingEnum(final Type type) {
        super.log.logf(FQCN, DEBUG, null, processingEnum$str(), type);
    }
    protected String processingEnum$str() {
        return "SROAP31010: Processing an enum %s";
    }
    @Override
    public final void typeNotInJandexIndex(final Type type) {
        super.log.logf(FQCN, DEBUG, null, typeNotInJandexIndex$str(), type);
    }
    protected String typeNotInJandexIndex$str() {
        return "SROAP31011: Encountered type not in Jandex index that is not well-known type. Will not traverse it: %s";
    }
    @Override
    public final void resolvedType(final Type type, final Type resolvedType) {
        super.log.logf(FQCN, DEBUG, null, resolvedType$str(), type, resolvedType);
    }
    protected String resolvedType$str() {
        return "SROAP31012: Resolved type %s -> %s";
    }
    @Override
    public final void terminalType(final Type type) {
        super.log.logf(FQCN, DEBUG, null, terminalType$str(), type);
    }
    protected String terminalType$str() {
        return "SROAP31013: Is a terminal type %s";
    }
    @Override
    public final void typeVarSubstitution(final Type type, final Type resolvedType) {
        super.log.logf(FQCN, DEBUG, null, typeVarSubstitution$str(), type, resolvedType);
    }
    protected String typeVarSubstitution$str() {
        return "SROAP31014: Attempting to do TYPE_VARIABLE substitution: %s -> %s";
    }
    @Override
    public final void classNotAvailable(final Type type) {
        super.log.logf(FQCN, DEBUG, null, classNotAvailable1$str(), type);
    }
    protected String classNotAvailable1$str() {
        return "SROAP31015: Class for type %s not available";
    }
    @Override
    public final void classNotAvailable(final String classDeclaration, final String typeSignature) {
        super.log.logf(FQCN, ERROR, null, classNotAvailable2$str(), classDeclaration, typeSignature);
    }
    protected String classNotAvailable2$str() {
        return "SROAP31016: Unanticipated mismatch between type arguments and type variables declared on class\nClass: %s\nType: %s";
    }
    @Override
    public final void exceptionReadingEnumJsonValue(final String enumName, final String methodName, final Exception exception) {
        super.log.logf(FQCN, WARN, null, exceptionReadingEnumJsonValue$str(), enumName, methodName, exception);
    }
    protected String exceptionReadingEnumJsonValue$str() {
        return "SROAP31017: Failed to read enumeration values from enum %s method %s with `@JsonValue`: %s";
    }
}
